from uuid import UUID

from tortoise.exceptions import ValidationError

from ..base import BaseController
from .services import OrderService
from exceptions import common as common_exc, http as http_exc


class OrderController(BaseController):
    order_service = OrderService()

    async def create(self, **kwargs):
        try:
            return await self.order_service.create_order(**kwargs)

        except common_exc.CreateException as e:
            raise http_exc.HTTPBadRequestException(detail=str(e))

        except ValidationError as e:
            raise http_exc.HTTPBadRequestException(detail=f"Validation error: {str(e)}")

    async def accepted_order(self, id: UUID):
        try:
            return await self.order_service.accepted_order(id)

        except common_exc.UpdateException as e:
            raise http_exc.HTTPBadRequestException(detail=str(e))

    async def get_order_status(self, id: UUID):
        try:
            return await self.order_service.get_order_status(id)

        except common_exc.NotFoundException as e:
            raise http_exc.HTTPNotFoundException(detail=str(e))
