from uuid import UUID

import fastapi as fa

from .ctrl import OrderController
from .schemas import OrderPostSchema, OrderIdSchema, OrderStatusSchema


router = fa.APIRouter(prefix='/orders', tags=['Order'])
ctrl = OrderController()


@router.post('')
async def create_order(body: OrderPostSchema):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.put('/accepted')
async def accepted_order(body: OrderIdSchema):
    order = await ctrl.accepted_order(**body.model_dump(exclude_none=True))
    return OrderStatusSchema.model_validate(order)


@router.get('/{id}/status')
async def get_order_status(id: UUID):
    order = await ctrl.get_order_status(id)
    return OrderStatusSchema.model_validate(order)
