from db.repositories.product import ProductRepository
from .schemas import ProductGetSchema
from adapters import MinioClient
import settings


class ProductService:
    product_repository = ProductRepository()
    client = MinioClient()

    async def create_product(self, **kwargs):
        image = kwargs.get('image')
        await self.client.upload_from_bytes(file=image)

        product = await self.product_repository.create(
            name=kwargs.get('name'),
            description=kwargs.get('description'),
            price=kwargs.get('price'),
            image=f"minio://{settings.minio_bucket_name}/{image.filename}",
        )

        return ProductGetSchema.model_validate(product)

    async def get_product_list(self, **kwargs):
        products = await self.product_repository.get_list(**kwargs)
        return {
            "page": products['page'],
            "size": products['size'],
            "total": products['total'],
            "result": [ProductGetSchema.model_validate(product) for product in products['result']]
        }
